import { ActionHandler } from "./action_handler";
import { FileBodyWrapper } from "./file_body_wrapper";
import { ResponseHandler } from "./response_handler";
import { Param } from "../../../../../../routes/param";
import { ParameterMap } from "../../../../../../routes/parameter_map";
import { APIResponse } from "../../../../../../routes/controllers/api_response";
declare class AttachmentsOperations {
    private recordId;
    private moduleAPIName;
    /**
     * Creates an instance of AttachmentsOperations with the given parameters
     * @param moduleAPIName A string representing the moduleAPIName
     * @param recordId A bigint representing the recordId
     */
    constructor(moduleAPIName: string, recordId: bigint);
    /**
     * The method to download attachment
     * @param id A bigint representing the id
     * @returns An instance of APIResponse<ResponseHandler>
     * @throws SDKException
     */
    downloadAttachment(id: bigint): Promise<APIResponse<ResponseHandler>>;
    /**
     * The method to delete attachment
     * @param id A bigint representing the id
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    deleteAttachment(id: bigint): Promise<APIResponse<ActionHandler>>;
    /**
     * The method to get attachments
     * @param paramInstance An instance of ParameterMap
     * @returns An instance of APIResponse<ResponseHandler>
     * @throws SDKException
     */
    getAttachments(paramInstance?: ParameterMap): Promise<APIResponse<ResponseHandler>>;
    /**
     * The method to upload attachment
     * @param request An instance of FileBodyWrapper
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    uploadAttachment(request: FileBodyWrapper): Promise<APIResponse<ActionHandler>>;
    /**
     * The method to upload link attachment
     * @param paramInstance An instance of ParameterMap
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    uploadLinkAttachment(paramInstance?: ParameterMap): Promise<APIResponse<ActionHandler>>;
    /**
     * The method to delete attachments
     * @param paramInstance An instance of ParameterMap
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    deleteAttachments(paramInstance?: ParameterMap): Promise<APIResponse<ActionHandler>>;
}
declare class GetAttachmentsParam {
    static FIELDS: Param<string>;
    static PAGE: Param<number>;
    static PER_PAGE: Param<number>;
}
declare class UploadLinkAttachmentParam {
    static ATTACHMENTURL: Param<string>;
}
declare class DeleteAttachmentsParam {
    static IDS: Param<bigint>;
}
export { AttachmentsOperations as MasterModel, AttachmentsOperations as AttachmentsOperations, DeleteAttachmentsParam as DeleteAttachmentsParam, UploadLinkAttachmentParam as UploadLinkAttachmentParam, GetAttachmentsParam as GetAttachmentsParam };
