import { ActionResponse } from "./action_response";
import { FileBodyWrapper } from "./file_body_wrapper";
import { RequestWrapper } from "./request_wrapper";
import { ResponseHandler } from "./response_handler";
import { ResponseWrapper } from "./response_wrapper";
import { Header } from "../../../../../../routes/header";
import { HeaderMap } from "../../../../../../routes/header_map";
import { APIResponse } from "../../../../../../routes/controllers/api_response";
declare class BulkWriteOperations {
    /**
     * The method to upload file
     * @param request An instance of FileBodyWrapper
     * @param headerInstance An instance of HeaderMap
     * @returns An instance of APIResponse<ActionResponse>
     * @throws SDKException
     */
    uploadFile(request: FileBodyWrapper, headerInstance?: HeaderMap): Promise<APIResponse<ActionResponse>>;
    /**
     * The method to create bulk write job
     * @param request An instance of RequestWrapper
     * @returns An instance of APIResponse<ActionResponse>
     * @throws SDKException
     */
    createBulkWriteJob(request: RequestWrapper): Promise<APIResponse<ActionResponse>>;
    /**
     * The method to get bulk write job details
     * @param jobId A bigint representing the jobId
     * @returns An instance of APIResponse<ResponseWrapper>
     * @throws SDKException
     */
    getBulkWriteJobDetails(jobId: bigint): Promise<APIResponse<ResponseWrapper>>;
    /**
     * The method to download bulk write result
     * @param downloadUrl A string representing the downloadUrl
     * @returns An instance of APIResponse<ResponseHandler>
     * @throws SDKException
     */
    downloadBulkWriteResult(downloadUrl: string): Promise<APIResponse<ResponseHandler>>;
}
declare class UploadFileHeader {
    static FEATURE: Header<string>;
    static X_CRM_ORG: Header<string>;
}
export { BulkWriteOperations as MasterModel, BulkWriteOperations as BulkWriteOperations, UploadFileHeader as UploadFileHeader };
