import { ActionHandler } from "./action_handler";
import { BaseCurrencyActionHandler } from "./base_currency_action_handler";
import { BaseCurrencyWrapper } from "./base_currency_wrapper";
import { BodyWrapper } from "./body_wrapper";
import { ResponseHandler } from "./response_handler";
import { APIResponse } from "../../../../../../routes/controllers/api_response";
declare class CurrenciesOperations {
    /**
     * The method to get currencies
     * @returns An instance of APIResponse<ResponseHandler>
     * @throws SDKException
     */
    getCurrencies(): Promise<APIResponse<ResponseHandler>>;
    /**
     * The method to add currencies
     * @param request An instance of BodyWrapper
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    addCurrencies(request: BodyWrapper): Promise<APIResponse<ActionHandler>>;
    /**
     * The method to update currencies
     * @param request An instance of BodyWrapper
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    updateCurrencies(request: BodyWrapper): Promise<APIResponse<ActionHandler>>;
    /**
     * The method to enable multiple currencies
     * @param request An instance of BaseCurrencyWrapper
     * @returns An instance of APIResponse<BaseCurrencyActionHandler>
     * @throws SDKException
     */
    enableMultipleCurrencies(request: BaseCurrencyWrapper): Promise<APIResponse<BaseCurrencyActionHandler>>;
    /**
     * The method to update base currency
     * @param request An instance of BaseCurrencyWrapper
     * @returns An instance of APIResponse<BaseCurrencyActionHandler>
     * @throws SDKException
     */
    updateBaseCurrency(request: BaseCurrencyWrapper): Promise<APIResponse<BaseCurrencyActionHandler>>;
    /**
     * The method to get currency
     * @param id A bigint representing the id
     * @returns An instance of APIResponse<ResponseHandler>
     * @throws SDKException
     */
    getCurrency(id: bigint): Promise<APIResponse<ResponseHandler>>;
    /**
     * The method to update currency
     * @param id A bigint representing the id
     * @param request An instance of BodyWrapper
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    updateCurrency(id: bigint, request: BodyWrapper): Promise<APIResponse<ActionHandler>>;
}
export { CurrenciesOperations as MasterModel, CurrenciesOperations as CurrenciesOperations };
