"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GetFieldAttachmentsParam = exports.FieldAttachmentsOperations = exports.MasterModel = void 0;
const param_1 = require("../../../../../../routes/param");
const common_api_handler_1 = require("../../../../../../routes/middlewares/common_api_handler");
const constants_1 = require("../../../../../../utils/util/constants");
class FieldAttachmentsOperations {
    /**
     * Creates an instance of FieldAttachmentsOperations with the given parameters
     * @param moduleAPIName A string representing the moduleAPIName
     * @param recordId A bigint representing the recordId
     * @param fieldsAttachmentId A bigint representing the fieldsAttachmentId
     */
    constructor(moduleAPIName, recordId, fieldsAttachmentId) {
        this.moduleAPIName = moduleAPIName;
        this.recordId = recordId;
        this.fieldsAttachmentId = fieldsAttachmentId;
    }
    /**
     * The method to get field attachments
     * @returns An instance of APIResponse<ResponseHandler>
     * @throws SDKException
     */
    async getFieldAttachments() {
        let handlerInstance = new common_api_handler_1.CommonAPIHandler();
        let apiPath = '';
        apiPath = apiPath.concat("/crm/v2.1/");
        apiPath = apiPath.concat(this.moduleAPIName.toString());
        apiPath = apiPath.concat("/");
        apiPath = apiPath.concat(this.recordId.toString());
        apiPath = apiPath.concat("/actions/download_fields_attachment");
        handlerInstance.setAPIPath(apiPath);
        handlerInstance.setHttpMethod(constants_1.Constants.REQUEST_METHOD_GET);
        handlerInstance.setCategoryMethod(constants_1.Constants.REQUEST_CATEGORY_READ);
        await handlerInstance.addParam(new param_1.Param("fields_attachment_id", "com.zoho.crm.api.FieldAttachments.GetFieldAttachmentsParam"), this.fieldsAttachmentId);
        let ResponseHandler = require.resolve("./response_handler");
        return handlerInstance.apiCall(ResponseHandler, "application/x-download");
    }
}
exports.MasterModel = FieldAttachmentsOperations;
exports.FieldAttachmentsOperations = FieldAttachmentsOperations;
class GetFieldAttachmentsParam {
}
exports.GetFieldAttachmentsParam = GetFieldAttachmentsParam;
