"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GetInventoryTemplatesParam = exports.InventoryTemplatesOperations = exports.MasterModel = exports.GetInventoryTemplatebyIDParam = void 0;
const param_1 = require("../../../../../../routes/param");
const common_api_handler_1 = require("../../../../../../routes/middlewares/common_api_handler");
const constants_1 = require("../../../../../../utils/util/constants");
class InventoryTemplatesOperations {
    /**
     * Creates an instance of InventoryTemplatesOperations with the given parameters
     * @param sortBy A string representing the sortBy
     * @param sortOrder A string representing the sortOrder
     * @param category A string representing the category
     */
    constructor(sortBy, sortOrder, category) {
        this.sortBy = sortBy;
        this.sortOrder = sortOrder;
        this.category = category;
    }
    /**
     * The method to get inventory templates
     * @param paramInstance An instance of ParameterMap
     * @returns An instance of APIResponse<ResponseHandler>
     * @throws SDKException
     */
    async getInventoryTemplates(paramInstance) {
        let handlerInstance = new common_api_handler_1.CommonAPIHandler();
        let apiPath = '';
        apiPath = apiPath.concat("/crm/v2.1/settings/inventory_templates");
        handlerInstance.setAPIPath(apiPath);
        handlerInstance.setHttpMethod(constants_1.Constants.REQUEST_METHOD_GET);
        handlerInstance.setCategoryMethod(constants_1.Constants.REQUEST_CATEGORY_READ);
        await handlerInstance.addParam(new param_1.Param("sort_by", "com.zoho.crm.api.InventoryTemplates.GetInventoryTemplatesParam"), this.sortBy);
        await handlerInstance.addParam(new param_1.Param("sort_order", "com.zoho.crm.api.InventoryTemplates.GetInventoryTemplatesParam"), this.sortOrder);
        await handlerInstance.addParam(new param_1.Param("category", "com.zoho.crm.api.InventoryTemplates.GetInventoryTemplatesParam"), this.category);
        handlerInstance.setParam(paramInstance);
        let ResponseHandler = require.resolve("./response_handler");
        return handlerInstance.apiCall(ResponseHandler, "application/json");
    }
    /**
     * The method to get inventory template by id
     * @param id A bigint representing the id
     * @returns An instance of APIResponse<ResponseHandler>
     * @throws SDKException
     */
    async getInventoryTemplateById(id) {
        let handlerInstance = new common_api_handler_1.CommonAPIHandler();
        let apiPath = '';
        apiPath = apiPath.concat("/crm/v2.1/settings/inventory_templates/");
        apiPath = apiPath.concat(id.toString());
        handlerInstance.setAPIPath(apiPath);
        handlerInstance.setHttpMethod(constants_1.Constants.REQUEST_METHOD_GET);
        handlerInstance.setCategoryMethod(constants_1.Constants.REQUEST_CATEGORY_READ);
        await handlerInstance.addParam(new param_1.Param("sort_by", "com.zoho.crm.api.InventoryTemplates.GetInventoryTemplatebyIDParam"), this.sortBy);
        await handlerInstance.addParam(new param_1.Param("sort_order", "com.zoho.crm.api.InventoryTemplates.GetInventoryTemplatebyIDParam"), this.sortOrder);
        await handlerInstance.addParam(new param_1.Param("category", "com.zoho.crm.api.InventoryTemplates.GetInventoryTemplatebyIDParam"), this.category);
        let ResponseHandler = require.resolve("./response_handler");
        return handlerInstance.apiCall(ResponseHandler, "application/json");
    }
}
exports.MasterModel = InventoryTemplatesOperations;
exports.InventoryTemplatesOperations = InventoryTemplatesOperations;
class GetInventoryTemplatesParam {
}
exports.GetInventoryTemplatesParam = GetInventoryTemplatesParam;
GetInventoryTemplatesParam.MODULE = new param_1.Param("module", "com.zoho.crm.api.InventoryTemplates.GetInventoryTemplatesParam");
class GetInventoryTemplatebyIDParam {
}
exports.GetInventoryTemplatebyIDParam = GetInventoryTemplatebyIDParam;
