import { ActionHandler } from "./action_handler";
import { BodyWrapper } from "./body_wrapper";
import { ResponseHandler } from "./response_handler";
import { TransferActionHandler } from "./transfer_action_handler";
import { TransferAndDeleteWrapper } from "./transfer_and_delete_wrapper";
import { APIResponse } from "../../../../../../routes/controllers/api_response";
declare class PipelineOperations {
    private layoutId?;
    /**
     * Creates an instance of PipelineOperations with the given parameters
     * @param layoutId A bigint representing the layoutId
     */
    constructor(layoutId?: bigint);
    /**
     * The method to transfer and delete
     * @param request An instance of TransferAndDeleteWrapper
     * @returns An instance of APIResponse<TransferActionHandler>
     * @throws SDKException
     */
    transferAndDelete(request: TransferAndDeleteWrapper): Promise<APIResponse<TransferActionHandler>>;
    /**
     * The method to get pipelines
     * @returns An instance of APIResponse<ResponseHandler>
     * @throws SDKException
     */
    getPipelines(): Promise<APIResponse<ResponseHandler>>;
    /**
     * The method to create pipelines
     * @param request An instance of BodyWrapper
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    createPipelines(request: BodyWrapper): Promise<APIResponse<ActionHandler>>;
    /**
     * The method to update pipelines
     * @param request An instance of BodyWrapper
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    updatePipelines(request: BodyWrapper): Promise<APIResponse<ActionHandler>>;
    /**
     * The method to get pipeline
     * @param pipelineId A bigint representing the pipelineId
     * @returns An instance of APIResponse<ResponseHandler>
     * @throws SDKException
     */
    getPipeline(pipelineId: bigint): Promise<APIResponse<ResponseHandler>>;
    /**
     * The method to update pipeline
     * @param pipelineId A bigint representing the pipelineId
     * @param request An instance of BodyWrapper
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    updatePipeline(pipelineId: bigint, request: BodyWrapper): Promise<APIResponse<ActionHandler>>;
}
declare class TransferAndDeleteParam {
}
declare class GetPipelinesParam {
}
declare class CreatePipelinesParam {
}
declare class UpdatePipelinesParam {
}
declare class GetPipelineParam {
}
declare class UpdatePipelineParam {
}
export { GetPipelineParam as GetPipelineParam, TransferAndDeleteParam as TransferAndDeleteParam, GetPipelinesParam as GetPipelinesParam, PipelineOperations as MasterModel, PipelineOperations as PipelineOperations, UpdatePipelinesParam as UpdatePipelinesParam, UpdatePipelineParam as UpdatePipelineParam, CreatePipelinesParam as CreatePipelinesParam };
