"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TransferPipeLine = exports.MasterModel = void 0;
class TransferPipeLine {
    constructor() {
        this.keyModified = new Map();
    }
    /**
     * The method to get the pipeline
     * @returns An instance of Pipeline
     */
    getPipeline() {
        return this.pipeline;
    }
    /**
     * The method to set the value to pipeline
     * @param pipeline An instance of Pipeline
     */
    setPipeline(pipeline) {
        this.pipeline = pipeline;
        this.keyModified.set("pipeline", 1);
    }
    /**
     * The method to get the stages
     * @returns An Array representing the stages
     */
    getStages() {
        return this.stages;
    }
    /**
     * The method to set the value to stages
     * @param stages An Array representing the stages
     */
    setStages(stages) {
        this.stages = stages;
        this.keyModified.set("stages", 1);
    }
    /**
     * The method to check if the user has modified the given key
     * @param key A string representing the key
     * @returns A number representing the modification
     */
    isKeyModified(key) {
        if (this.keyModified.has(key)) {
            return this.keyModified.get(key);
        }
        return null;
    }
    /**
     * The method to mark the given key as modified
     * @param key A string representing the key
     * @param modification A number representing the modification
     */
    setKeyModified(key, modification) {
        this.keyModified.set(key, modification);
    }
}
exports.MasterModel = TransferPipeLine;
exports.TransferPipeLine = TransferPipeLine;
