import { Layout } from "../layouts/layout";
import { Participants } from "./participants";
import { PricingDetails } from "./pricing_details";
import { Record } from "./record";
import { RecurringActivity } from "./recurring_activity";
import { RemindAt } from "./remind_at";
import { Tax } from "./tax";
import { Tag } from "../tags/tag";
import { User } from "../users/user";
import { Choice } from "../../../../../../utils/util/choice";
declare class Field<T = any> {
    private apiName;
    /**
     * Creates an instance of Field with the given parameters
     * @param apiName A string representing the apiName
     */
    constructor(apiName: string);
    /**
     * The method to get the apiName
     * @returns A string representing the apiName
     */
    getAPIName(): string;
    static Products: {
        new (): {};
        PRODUCT_CATEGORY: Field<Choice<string>>;
        QTY_IN_DEMAND: Field<number>;
        OWNER: Field<User>;
        DESCRIPTION: Field<string>;
        VENDOR_NAME: Field<Record>;
        TAX: Field<Array<Tax>>;
        SALES_START_DATE: Field<Date>;
        PRODUCT_ACTIVE: Field<boolean>;
        RECORD_IMAGE: Field<string>;
        MODIFIED_BY: Field<User>;
        PRODUCT_CODE: Field<string>;
        MANUFACTURER: Field<Choice<string>>;
        ID: Field<bigint>;
        SUPPORT_EXPIRY_DATE: Field<Date>;
        MODIFIED_TIME: Field<Date>;
        CREATED_TIME: Field<Date>;
        COMMISSION_RATE: Field<number>;
        PRODUCT_NAME: Field<string>;
        HANDLER: Field<User>;
        SUPPORT_START_DATE: Field<Date>;
        USAGE_UNIT: Field<Choice<string>>;
        QTY_ORDERED: Field<number>;
        QTY_IN_STOCK: Field<number>;
        CREATED_BY: Field<User>;
        TAG: Field<Array<Tag>>;
        SALES_END_DATE: Field<Date>;
        UNIT_PRICE: Field<number>;
        TAXABLE: Field<boolean>;
        REORDER_LEVEL: Field<number>;
    };
    static Tasks: {
        new (): {};
        STATUS: Field<Choice<string>>;
        OWNER: Field<User>;
        MODIFIED_TIME: Field<Date>;
        DESCRIPTION: Field<string>;
        DUE_DATE: Field<Date>;
        PRIORITY: Field<Choice<string>>;
        CREATED_TIME: Field<Date>;
        CLOSED_TIME: Field<Date>;
        SUBJECT: Field<string>;
        SEND_NOTIFICATION_EMAIL: Field<boolean>;
        MODIFIED_BY: Field<User>;
        RECURRING_ACTIVITY: Field<RecurringActivity>;
        WHAT_ID: Field<Record>;
        ID: Field<bigint>;
        CREATED_BY: Field<User>;
        TAG: Field<Array<Tag>>;
        REMIND_AT: Field<RemindAt>;
        WHO_ID: Field<Record>;
    };
    static Vendors: {
        new (): {};
        OWNER: Field<User>;
        MODIFIED_TIME: Field<Date>;
        EMAIL: Field<string>;
        CATEGORY: Field<string>;
        DESCRIPTION: Field<string>;
        VENDOR_NAME: Field<string>;
        CREATED_TIME: Field<Date>;
        WEBSITE: Field<string>;
        CITY: Field<string>;
        RECORD_IMAGE: Field<string>;
        MODIFIED_BY: Field<User>;
        PHONE: Field<string>;
        STATE: Field<string>;
        GL_ACCOUNT: Field<Choice<string>>;
        STREET: Field<string>;
        COUNTRY: Field<string>;
        ZIP_CODE: Field<string>;
        ID: Field<bigint>;
        CREATED_BY: Field<User>;
        TAG: Field<Array<Tag>>;
    };
    static Calls: {
        new (): {};
        CALL_DURATION: Field<string>;
        OWNER: Field<User>;
        MODIFIED_TIME: Field<Date>;
        DESCRIPTION: Field<string>;
        REMINDER: Field<Choice<string>>;
        CALLER_ID: Field<string>;
        CTI_ENTRY: Field<boolean>;
        CREATED_TIME: Field<Date>;
        CALL_START_TIME: Field<Date>;
        SUBJECT: Field<string>;
        CALL_AGENDA: Field<string>;
        CALL_RESULT: Field<string>;
        CALL_TYPE: Field<Choice<string>>;
        MODIFIED_BY: Field<User>;
        WHAT_ID: Field<Record>;
        CALL_DURATION_IN_SECONDS: Field<number>;
        CALL_PURPOSE: Field<Choice<string>>;
        ID: Field<bigint>;
        CREATED_BY: Field<User>;
        TAG: Field<Array<Tag>>;
        DIALLED_NUMBER: Field<string>;
        CALL_STATUS: Field<Choice<string>>;
        WHO_ID: Field<Record>;
    };
    static Leads: {
        new (): {};
        OWNER: Field<User>;
        COMPANY: Field<string>;
        EMAIL: Field<string>;
        DESCRIPTION: Field<string>;
        RATING: Field<Choice<string>>;
        WEBSITE: Field<string>;
        TWITTER: Field<string>;
        SALUTATION: Field<Choice<string>>;
        LAST_ACTIVITY_TIME: Field<Date>;
        FIRST_NAME: Field<string>;
        FULL_NAME: Field<string>;
        LEAD_STATUS: Field<Choice<string>>;
        INDUSTRY: Field<Choice<string>>;
        RECORD_IMAGE: Field<string>;
        MODIFIED_BY: Field<User>;
        SKYPE_ID: Field<string>;
        PHONE: Field<string>;
        STREET: Field<string>;
        ZIP_CODE: Field<string>;
        ID: Field<bigint>;
        EMAIL_OPT_OUT: Field<boolean>;
        DESIGNATION: Field<string>;
        MODIFIED_TIME: Field<Date>;
        CREATED_TIME: Field<Date>;
        CITY: Field<string>;
        NO_OF_EMPLOYEES: Field<number>;
        MOBILE: Field<string>;
        CONVERTED_DATE_TIME: Field<Date>;
        LAST_NAME: Field<string>;
        LAYOUT: Field<Layout>;
        STATE: Field<string>;
        LEAD_SOURCE: Field<Choice<string>>;
        IS_RECORD_DUPLICATE: Field<boolean>;
        TAG: Field<Array<Tag>>;
        CREATED_BY: Field<User>;
        FAX: Field<string>;
        ANNUAL_REVENUE: Field<number>;
        SECONDARY_EMAIL: Field<string>;
    };
    static Deals: {
        new (): {};
        OWNER: Field<User>;
        DESCRIPTION: Field<string>;
        CAMPAIGN_SOURCE: Field<Record>;
        CLOSING_DATE: Field<Date>;
        LAST_ACTIVITY_TIME: Field<Date>;
        MODIFIED_BY: Field<User>;
        LEAD_CONVERSION_TIME: Field<number>;
        DEAL_NAME: Field<string>;
        EXPECTED_REVENUE: Field<number>;
        OVERALL_SALES_DURATION: Field<number>;
        STAGE: Field<Choice<string>>;
        ID: Field<bigint>;
        MODIFIED_TIME: Field<Date>;
        TERRITORY: Field<string>;
        CREATED_TIME: Field<Date>;
        AMOUNT: Field<number>;
        PROBABILITY: Field<number>;
        NEXT_STEP: Field<string>;
        CONTACT_NAME: Field<Record>;
        SALES_CYCLE_DURATION: Field<number>;
        TYPE: Field<Choice<string>>;
        DEAL_CATEGORY_STATUS: Field<Choice<string>>;
        LEAD_SOURCE: Field<Choice<string>>;
        CREATED_BY: Field<User>;
        TAG: Field<Array<Tag>>;
    };
    static Campaigns: {
        new (): {};
        STATUS: Field<Choice<string>>;
        OWNER: Field<User>;
        MODIFIED_TIME: Field<Date>;
        DESCRIPTION: Field<string>;
        CAMPAIGN_NAME: Field<string>;
        CREATED_TIME: Field<Date>;
        END_DATE: Field<Date>;
        TYPE: Field<Choice<string>>;
        MODIFIED_BY: Field<User>;
        NUM_SENT: Field<bigint>;
        EXPECTED_REVENUE: Field<number>;
        ACTUAL_COST: Field<number>;
        ID: Field<bigint>;
        EXPECTED_RESPONSE: Field<bigint>;
        CREATED_BY: Field<User>;
        TAG: Field<Array<Tag>>;
        PARENT_CAMPAIGN: Field<Record>;
        START_DATE: Field<Date>;
        BUDGETED_COST: Field<number>;
    };
    static Quotes: {
        new (): {};
        OWNER: Field<User>;
        DISCOUNT: Field<number>;
        DESCRIPTION: Field<string>;
        SHIPPING_STATE: Field<string>;
        TAX: Field<number>;
        MODIFIED_BY: Field<User>;
        DEAL_NAME: Field<Record>;
        VALID_TILL: Field<Date>;
        BILLING_COUNTRY: Field<string>;
        ACCOUNT_NAME: Field<Record>;
        TEAM: Field<string>;
        ID: Field<bigint>;
        CARRIER: Field<Choice<string>>;
        QUOTED_ITEMS: Field<Array<Record>>;
        QUOTE_STAGE: Field<Choice<string>>;
        GRAND_TOTAL: Field<number>;
        MODIFIED_TIME: Field<Date>;
        BILLING_STREET: Field<string>;
        ADJUSTMENT: Field<number>;
        CREATED_TIME: Field<Date>;
        TERMS_AND_CONDITIONS: Field<string>;
        SUB_TOTAL: Field<number>;
        BILLING_CODE: Field<string>;
        SUBJECT: Field<string>;
        CONTACT_NAME: Field<Record>;
        SHIPPING_CITY: Field<string>;
        SHIPPING_COUNTRY: Field<string>;
        SHIPPING_CODE: Field<string>;
        BILLING_CITY: Field<string>;
        QUOTE_NUMBER: Field<bigint>;
        BILLING_STATE: Field<string>;
        CREATED_BY: Field<User>;
        TAG: Field<Array<Tag>>;
        SHIPPING_STREET: Field<string>;
    };
    static Invoices: {
        new (): {};
        OWNER: Field<User>;
        DISCOUNT: Field<number>;
        DESCRIPTION: Field<string>;
        SHIPPING_STATE: Field<string>;
        TAX: Field<number>;
        INVOICE_DATE: Field<Date>;
        MODIFIED_BY: Field<User>;
        INVOICED_ITEMS: Field<Array<Record>>;
        BILLING_COUNTRY: Field<string>;
        ACCOUNT_NAME: Field<Record>;
        ID: Field<bigint>;
        SALES_ORDER: Field<Record>;
        STATUS: Field<Choice<string>>;
        GRAND_TOTAL: Field<number>;
        SALES_COMMISSION: Field<number>;
        MODIFIED_TIME: Field<Date>;
        DUE_DATE: Field<Date>;
        BILLING_STREET: Field<string>;
        ADJUSTMENT: Field<number>;
        CREATED_TIME: Field<Date>;
        TERMS_AND_CONDITIONS: Field<string>;
        SUB_TOTAL: Field<number>;
        INVOICE_NUMBER: Field<bigint>;
        BILLING_CODE: Field<string>;
        SUBJECT: Field<string>;
        CONTACT_NAME: Field<Record>;
        EXCISE_DUTY: Field<number>;
        SHIPPING_CITY: Field<string>;
        SHIPPING_COUNTRY: Field<string>;
        SHIPPING_CODE: Field<string>;
        BILLING_CITY: Field<string>;
        PURCHASE_ORDER: Field<string>;
        BILLING_STATE: Field<string>;
        CREATED_BY: Field<User>;
        TAG: Field<Array<Tag>>;
        SHIPPING_STREET: Field<string>;
    };
    static Attachments: {
        new (): {};
        OWNER: Field<User>;
        MODIFIED_BY: Field<User>;
        MODIFIED_TIME: Field<Date>;
        FILE_NAME: Field<string>;
        CREATED_TIME: Field<Date>;
        SIZE: Field<string>;
        PARENT_ID: Field<Record>;
        ID: Field<bigint>;
        CREATED_BY: Field<User>;
    };
    static Price_Books: {
        new (): {};
        OWNER: Field<User>;
        ACTIVE: Field<boolean>;
        MODIFIED_BY: Field<User>;
        MODIFIED_TIME: Field<Date>;
        PRICING_DETAILS: Field<Array<PricingDetails>>;
        PRICING_MODEL: Field<Choice<string>>;
        DESCRIPTION: Field<string>;
        CREATED_TIME: Field<Date>;
        PRICE_BOOK_NAME: Field<string>;
        ID: Field<bigint>;
        CREATED_BY: Field<User>;
        TAG: Field<Array<Tag>>;
    };
    static Sales_Orders: {
        new (): {};
        OWNER: Field<User>;
        DISCOUNT: Field<number>;
        DESCRIPTION: Field<string>;
        CUSTOMER_NO: Field<string>;
        SHIPPING_STATE: Field<string>;
        TAX: Field<number>;
        MODIFIED_BY: Field<User>;
        DEAL_NAME: Field<Record>;
        BILLING_COUNTRY: Field<string>;
        ACCOUNT_NAME: Field<Record>;
        ID: Field<bigint>;
        CARRIER: Field<Choice<string>>;
        ORDERED_ITEMS: Field<Array<Record>>;
        QUOTE_NAME: Field<Record>;
        STATUS: Field<Choice<string>>;
        SALES_COMMISSION: Field<number>;
        GRAND_TOTAL: Field<number>;
        MODIFIED_TIME: Field<Date>;
        DUE_DATE: Field<Date>;
        BILLING_STREET: Field<string>;
        ADJUSTMENT: Field<number>;
        CREATED_TIME: Field<Date>;
        TERMS_AND_CONDITIONS: Field<string>;
        SUB_TOTAL: Field<number>;
        BILLING_CODE: Field<string>;
        SUBJECT: Field<string>;
        CONTACT_NAME: Field<Record>;
        EXCISE_DUTY: Field<number>;
        SHIPPING_CITY: Field<string>;
        SHIPPING_COUNTRY: Field<string>;
        SHIPPING_CODE: Field<string>;
        BILLING_CITY: Field<string>;
        SO_NUMBER: Field<bigint>;
        PURCHASE_ORDER: Field<string>;
        BILLING_STATE: Field<string>;
        CREATED_BY: Field<User>;
        TAG: Field<Array<Tag>>;
        PENDING: Field<string>;
        SHIPPING_STREET: Field<string>;
    };
    static Contacts: {
        new (): {};
        OWNER: Field<User>;
        EMAIL: Field<string>;
        DESCRIPTION: Field<string>;
        VENDOR_NAME: Field<Record>;
        MAILING_ZIP: Field<string>;
        REPORTS_TO: Field<string>;
        OTHER_PHONE: Field<string>;
        MAILING_STATE: Field<string>;
        TWITTER: Field<string>;
        OTHER_ZIP: Field<string>;
        MAILING_STREET: Field<string>;
        OTHER_STATE: Field<string>;
        SALUTATION: Field<Choice<string>>;
        OTHER_COUNTRY: Field<string>;
        LAST_ACTIVITY_TIME: Field<Date>;
        FIRST_NAME: Field<string>;
        FULL_NAME: Field<string>;
        ASST_PHONE: Field<string>;
        RECORD_IMAGE: Field<string>;
        DEPARTMENT: Field<string>;
        MODIFIED_BY: Field<User>;
        SKYPE_ID: Field<string>;
        ASSISTANT: Field<string>;
        PHONE: Field<string>;
        MAILING_COUNTRY: Field<string>;
        ACCOUNT_NAME: Field<Record>;
        ID: Field<bigint>;
        EMAIL_OPT_OUT: Field<boolean>;
        REPORTING_TO: Field<Record>;
        MODIFIED_TIME: Field<Date>;
        DATE_OF_BIRTH: Field<Date>;
        MAILING_CITY: Field<string>;
        OTHER_CITY: Field<string>;
        CREATED_TIME: Field<Date>;
        TITLE: Field<string>;
        OTHER_STREET: Field<string>;
        MOBILE: Field<string>;
        TERRITORIES: Field<string>;
        HOME_PHONE: Field<string>;
        LAST_NAME: Field<string>;
        LEAD_SOURCE: Field<Choice<string>>;
        IS_RECORD_DUPLICATE: Field<boolean>;
        TAG: Field<Array<Tag>>;
        CREATED_BY: Field<User>;
        FAX: Field<string>;
        SECONDARY_EMAIL: Field<string>;
    };
    static Solutions: {
        new (): {};
        STATUS: Field<Choice<string>>;
        OWNER: Field<User>;
        MODIFIED_TIME: Field<Date>;
        CREATED_TIME: Field<Date>;
        COMMENTS: Field<string>;
        NO_OF_COMMENTS: Field<number>;
        PRODUCT_NAME: Field<Record>;
        ADD_COMMENT: Field<string>;
        SOLUTION_NUMBER: Field<bigint>;
        ANSWER: Field<string>;
        MODIFIED_BY: Field<User>;
        SOLUTION_TITLE: Field<string>;
        PUBLISHED: Field<boolean>;
        QUESTION: Field<string>;
        ID: Field<bigint>;
        CREATED_BY: Field<User>;
        TAG: Field<Array<Tag>>;
    };
    static Events: {
        new (): {};
        ALL_DAY: Field<boolean>;
        OWNER: Field<User>;
        CHECK_IN_STATE: Field<string>;
        CHECK_IN_ADDRESS: Field<string>;
        DESCRIPTION: Field<string>;
        START_DATETIME: Field<Date>;
        LATITUDE: Field<number>;
        PARTICIPANTS: Field<Array<Participants>>;
        EVENT_TITLE: Field<string>;
        END_DATETIME: Field<Date>;
        CHECK_IN_BY: Field<User>;
        MODIFIED_BY: Field<User>;
        CHECK_IN_CITY: Field<string>;
        ID: Field<bigint>;
        CHECK_IN_COMMENT: Field<string>;
        REMIND_AT: Field<Date>;
        WHO_ID: Field<Record>;
        CHECK_IN_STATUS: Field<string>;
        CHECK_IN_COUNTRY: Field<string>;
        MODIFIED_TIME: Field<Date>;
        VENUE: Field<string>;
        ZIP_CODE: Field<string>;
        CREATED_TIME: Field<Date>;
        LONGITUDE: Field<number>;
        CHECK_IN_TIME: Field<Date>;
        RECURRING_ACTIVITY: Field<RecurringActivity>;
        WHAT_ID: Field<Record>;
        CHECK_IN_SUB_LOCALITY: Field<string>;
        CREATED_BY: Field<User>;
        TAG: Field<Array<Tag>>;
    };
    static Purchase_Orders: {
        new (): {};
        OWNER: Field<User>;
        DISCOUNT: Field<number>;
        DESCRIPTION: Field<string>;
        VENDOR_NAME: Field<Record>;
        SHIPPING_STATE: Field<string>;
        TAX: Field<number>;
        PO_DATE: Field<Date>;
        MODIFIED_BY: Field<User>;
        BILLING_COUNTRY: Field<string>;
        PURCHASE_ITEMS: Field<Array<Record>>;
        ID: Field<bigint>;
        CARRIER: Field<Choice<string>>;
        STATUS: Field<Choice<string>>;
        GRAND_TOTAL: Field<number>;
        SALES_COMMISSION: Field<number>;
        MODIFIED_TIME: Field<Date>;
        PO_NUMBER: Field<string>;
        DUE_DATE: Field<Date>;
        BILLING_STREET: Field<string>;
        ADJUSTMENT: Field<number>;
        CREATED_TIME: Field<Date>;
        TERMS_AND_CONDITIONS: Field<string>;
        SUB_TOTAL: Field<number>;
        BILLING_CODE: Field<string>;
        SUBJECT: Field<string>;
        TRACKING_NUMBER: Field<string>;
        CONTACT_NAME: Field<Record>;
        EXCISE_DUTY: Field<number>;
        SHIPPING_CITY: Field<string>;
        SHIPPING_COUNTRY: Field<string>;
        SHIPPING_CODE: Field<string>;
        BILLING_CITY: Field<string>;
        REQUISITION_NO: Field<string>;
        BILLING_STATE: Field<string>;
        CREATED_BY: Field<User>;
        TAG: Field<Array<Tag>>;
        SHIPPING_STREET: Field<string>;
    };
    static Accounts: {
        new (): {};
        OWNER: Field<User>;
        OWNERSHIP: Field<Choice<string>>;
        DESCRIPTION: Field<string>;
        ACCOUNT_TYPE: Field<Choice<string>>;
        RATING: Field<Choice<string>>;
        SIC_CODE: Field<number>;
        SHIPPING_STATE: Field<string>;
        WEBSITE: Field<string>;
        EMPLOYEES: Field<number>;
        LAST_ACTIVITY_TIME: Field<Date>;
        INDUSTRY: Field<Choice<string>>;
        RECORD_IMAGE: Field<string>;
        MODIFIED_BY: Field<User>;
        ACCOUNT_SITE: Field<string>;
        PHONE: Field<string>;
        BILLING_COUNTRY: Field<string>;
        ACCOUNT_NAME: Field<string>;
        ID: Field<bigint>;
        ACCOUNT_NUMBER: Field<bigint>;
        TICKER_SYMBOL: Field<string>;
        MODIFIED_TIME: Field<Date>;
        BILLING_STREET: Field<string>;
        CREATED_TIME: Field<Date>;
        BILLING_CODE: Field<string>;
        TERRITORIES: Field<string>;
        PARENT_ACCOUNT: Field<Record>;
        SHIPPING_CITY: Field<string>;
        SHIPPING_COUNTRY: Field<string>;
        SHIPPING_CODE: Field<string>;
        BILLING_CITY: Field<string>;
        BILLING_STATE: Field<string>;
        TAG: Field<Array<Tag>>;
        CREATED_BY: Field<User>;
        FAX: Field<string>;
        ANNUAL_REVENUE: Field<number>;
        SHIPPING_STREET: Field<string>;
    };
    static Cases: {
        new (): {};
        OWNER: Field<User>;
        EMAIL: Field<string>;
        DESCRIPTION: Field<string>;
        INTERNAL_COMMENTS: Field<string>;
        NO_OF_COMMENTS: Field<number>;
        REPORTED_BY: Field<string>;
        CASE_NUMBER: Field<bigint>;
        MODIFIED_BY: Field<User>;
        DEAL_NAME: Field<Record>;
        PHONE: Field<string>;
        ACCOUNT_NAME: Field<Record>;
        ID: Field<bigint>;
        SOLUTION: Field<string>;
        STATUS: Field<Choice<string>>;
        MODIFIED_TIME: Field<Date>;
        PRIORITY: Field<Choice<string>>;
        CREATED_TIME: Field<Date>;
        COMMENTS: Field<string>;
        PRODUCT_NAME: Field<Record>;
        ADD_COMMENT: Field<string>;
        CASE_ORIGIN: Field<Choice<string>>;
        SUBJECT: Field<string>;
        CASE_REASON: Field<Choice<string>>;
        TYPE: Field<Choice<string>>;
        IS_RECORD_DUPLICATE: Field<boolean>;
        TAG: Field<Array<Tag>>;
        CREATED_BY: Field<User>;
        RELATED_TO: Field<Record>;
    };
    static Notes: {
        new (): {};
        OWNER: Field<User>;
        MODIFIED_BY: Field<User>;
        MODIFIED_TIME: Field<Date>;
        CREATED_TIME: Field<Date>;
        PARENT_ID: Field<Record>;
        ID: Field<bigint>;
        CREATED_BY: Field<User>;
        NOTE_TITLE: Field<string>;
        NOTE_CONTENT: Field<string>;
    };
}
export { Field as MasterModel, Field as Field };
