import { Param } from "../../../../../../routes/param";
import { ParameterMap } from "../../../../../../routes/parameter_map";
import { ActionHandler } from "./action_handler";
import { BodyWrapper } from "./body_wrapper";
import { CountHandler } from "./count_handler";
import { MergeWrapper } from "./merge_wrapper";
import { RecordActionHandler } from "./record_action_handler";
import { ResponseHandler } from "./response_handler";
import { APIResponse } from "../../../../../../routes/controllers/api_response";
declare class TagsOperations {
    /**
     * The method to get tags
     * @param paramInstance An instance of ParameterMap
     * @returns An instance of APIResponse<ResponseHandler>
     * @throws SDKException
     */
    getTags(paramInstance?: ParameterMap): Promise<APIResponse<ResponseHandler>>;
    /**
     * The method to create tags
     * @param request An instance of BodyWrapper
     * @param paramInstance An instance of ParameterMap
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    createTags(request: BodyWrapper, paramInstance?: ParameterMap): Promise<APIResponse<ActionHandler>>;
    /**
     * The method to update tags
     * @param request An instance of BodyWrapper
     * @param paramInstance An instance of ParameterMap
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    updateTags(request: BodyWrapper, paramInstance?: ParameterMap): Promise<APIResponse<ActionHandler>>;
    /**
     * The method to update tag
     * @param id A bigint representing the id
     * @param request An instance of BodyWrapper
     * @param paramInstance An instance of ParameterMap
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    updateTag(id: bigint, request: BodyWrapper, paramInstance?: ParameterMap): Promise<APIResponse<ActionHandler>>;
    /**
     * The method to delete tag
     * @param id A bigint representing the id
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    deleteTag(id: bigint): Promise<APIResponse<ActionHandler>>;
    /**
     * The method to merge tags
     * @param id A bigint representing the id
     * @param request An instance of MergeWrapper
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    mergeTags(id: bigint, request: MergeWrapper): Promise<APIResponse<ActionHandler>>;
    /**
     * The method to add tags to record
     * @param recordId A bigint representing the recordId
     * @param moduleAPIName A string representing the moduleAPIName
     * @param paramInstance An instance of ParameterMap
     * @returns An instance of APIResponse<RecordActionHandler>
     * @throws SDKException
     */
    addTagsToRecord(recordId: bigint, moduleAPIName: string, paramInstance?: ParameterMap): Promise<APIResponse<RecordActionHandler>>;
    /**
     * The method to remove tags from record
     * @param recordId A bigint representing the recordId
     * @param moduleAPIName A string representing the moduleAPIName
     * @param paramInstance An instance of ParameterMap
     * @returns An instance of APIResponse<RecordActionHandler>
     * @throws SDKException
     */
    removeTagsFromRecord(recordId: bigint, moduleAPIName: string, paramInstance?: ParameterMap): Promise<APIResponse<RecordActionHandler>>;
    /**
     * The method to add tags to multiple records
     * @param moduleAPIName A string representing the moduleAPIName
     * @param paramInstance An instance of ParameterMap
     * @returns An instance of APIResponse<RecordActionHandler>
     * @throws SDKException
     */
    addTagsToMultipleRecords(moduleAPIName: string, paramInstance?: ParameterMap): Promise<APIResponse<RecordActionHandler>>;
    /**
     * The method to remove tags from multiple records
     * @param moduleAPIName A string representing the moduleAPIName
     * @param paramInstance An instance of ParameterMap
     * @returns An instance of APIResponse<RecordActionHandler>
     * @throws SDKException
     */
    removeTagsFromMultipleRecords(moduleAPIName: string, paramInstance?: ParameterMap): Promise<APIResponse<RecordActionHandler>>;
    /**
     * The method to get record count for tag
     * @param id A bigint representing the id
     * @param paramInstance An instance of ParameterMap
     * @returns An instance of APIResponse<CountHandler>
     * @throws SDKException
     */
    getRecordCountForTag(id: bigint, paramInstance?: ParameterMap): Promise<APIResponse<CountHandler>>;
}
declare class GetTagsParam {
    static MODULE: Param<string>;
    static MY_TAGS: Param<string>;
}
declare class CreateTagsParam {
    static MODULE: Param<string>;
}
declare class UpdateTagsParam {
    static MODULE: Param<string>;
}
declare class UpdateTagParam {
    static MODULE: Param<string>;
}
declare class AddTagsToRecordParam {
    static TAG_NAMES: Param<string>;
    static OVER_WRITE: Param<string>;
}
declare class RemoveTagsFromRecordParam {
    static TAG_NAMES: Param<string>;
}
declare class AddTagsToMultipleRecordsParam {
    static TAG_NAMES: Param<string>;
    static IDS: Param<bigint>;
    static OVER_WRITE: Param<string>;
}
declare class RemoveTagsFromMultipleRecordsParam {
    static TAG_NAMES: Param<string>;
    static IDS: Param<bigint>;
}
declare class GetRecordCountForTagParam {
    static MODULE: Param<string>;
}
export { RemoveTagsFromMultipleRecordsParam as RemoveTagsFromMultipleRecordsParam, AddTagsToRecordParam as AddTagsToRecordParam, AddTagsToMultipleRecordsParam as AddTagsToMultipleRecordsParam, TagsOperations as MasterModel, TagsOperations as TagsOperations, RemoveTagsFromRecordParam as RemoveTagsFromRecordParam, GetRecordCountForTagParam as GetRecordCountForTagParam, UpdateTagsParam as UpdateTagsParam, UpdateTagParam as UpdateTagParam, GetTagsParam as GetTagsParam, CreateTagsParam as CreateTagsParam };
