import { Param } from "../../../../../../routes/param";
import { ParameterMap } from "../../../../../../routes/parameter_map";
import { ActionHandler } from "./action_handler";
import { BodyWrapper } from "./body_wrapper";
import { ResponseHandler } from "./response_handler";
import { APIResponse } from "../../../../../../routes/controllers/api_response";
declare class VariablesOperations {
    /**
     * The method to get variables
     * @param paramInstance An instance of ParameterMap
     * @returns An instance of APIResponse<ResponseHandler>
     * @throws SDKException
     */
    getVariables(paramInstance?: ParameterMap): Promise<APIResponse<ResponseHandler>>;
    /**
     * The method to create variables
     * @param request An instance of BodyWrapper
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    createVariables(request: BodyWrapper): Promise<APIResponse<ActionHandler>>;
    /**
     * The method to update variables
     * @param request An instance of BodyWrapper
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    updateVariables(request: BodyWrapper): Promise<APIResponse<ActionHandler>>;
    /**
     * The method to delete variables
     * @param paramInstance An instance of ParameterMap
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    deleteVariables(paramInstance?: ParameterMap): Promise<APIResponse<ActionHandler>>;
    /**
     * The method to get variable by id
     * @param id A bigint representing the id
     * @param paramInstance An instance of ParameterMap
     * @returns An instance of APIResponse<ResponseHandler>
     * @throws SDKException
     */
    getVariableById(id: bigint, paramInstance?: ParameterMap): Promise<APIResponse<ResponseHandler>>;
    /**
     * The method to update variable by id
     * @param id A bigint representing the id
     * @param request An instance of BodyWrapper
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    updateVariableById(id: bigint, request: BodyWrapper): Promise<APIResponse<ActionHandler>>;
    /**
     * The method to delete variable
     * @param id A bigint representing the id
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    deleteVariable(id: bigint): Promise<APIResponse<ActionHandler>>;
    /**
     * The method to get variable for api name
     * @param apiName A string representing the apiName
     * @param paramInstance An instance of ParameterMap
     * @returns An instance of APIResponse<ResponseHandler>
     * @throws SDKException
     */
    getVariableForAPIName(apiName: string, paramInstance?: ParameterMap): Promise<APIResponse<ResponseHandler>>;
    /**
     * The method to update variable by api name
     * @param apiName A string representing the apiName
     * @param request An instance of BodyWrapper
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    updateVariableByAPIName(apiName: string, request: BodyWrapper): Promise<APIResponse<ActionHandler>>;
}
declare class GetVariablesParam {
    static GROUP: Param<string>;
}
declare class DeleteVariablesParam {
    static IDS: Param<bigint>;
}
declare class GetVariableByIDParam {
    static GROUP: Param<string>;
}
declare class GetVariableForAPINameParam {
    static GROUP: Param<string>;
}
export { VariablesOperations as MasterModel, VariablesOperations as VariablesOperations, GetVariableByIDParam as GetVariableByIDParam, DeleteVariablesParam as DeleteVariablesParam, GetVariableForAPINameParam as GetVariableForAPINameParam, GetVariablesParam as GetVariablesParam };
