import { Converter } from '../../utils/util/converter';
import { RequestProxy } from '../request_proxy';
/**
 * This module is to make HTTP connections, trigger the requests and receive the response
 */
export declare class APIHTTPConnector {
    private url;
    private requestMethod;
    private headers;
    private parameters;
    private requestBody;
    private contentType;
    /**
     * This is a getter method to get the ContentType.
     * @returns A String representing the ContentType.
    */
    getContentType(): string | undefined;
    /**
     * This is a setter method to set the ContentType.
     * @param {string} contentType A String containing the ContentType.
    */
    setContentType(contentType: string | undefined): void;
    /**
     * This is a setter method to set the API URL.
     * @param {string} url A String containing the API Request URL.
    */
    setUrl(url: string): void;
    /**
     * This is a setter method to set the API request method.
     * @param {string} httpMethod - A String containing the API request method.
    */
    setRequestMethod(requestMethod: string): void;
    /**
     * This is a getter method to get API request headers.
     * @returns A Map representing the API request headers.
    */
    getHeaders(): Map<string, string>;
    /**
     * This is a setter method to set API request headers.
     * @param {Map} headers - A Map containing the API request headers.
    */
    setHeaders(headers: Map<string, string>): void;
    /**
     * This method to add API request header name and value.
     * @param {string} headerName - A String containing the API request header name.
     * @param {string} headerValue - A String containing the API request header value.
    */
    addHeader(headerName: string, headerValue: string): void;
    /**
     * This is a getter method to get API request parameters.
     * @returns A Map representing the API request parameters.
    */
    getParams(): Map<string, string>;
    /**
     * This is a setter method to set API request parameters.
     * @param {Map} params - A Map containing the API request parameters.
    */
    setParams(params: Map<string, string>): void;
    /**
     * This method to add API request param name and value.
     * @param {string} paramName - A String containing the API request param name.
     * @param {string} paramValue - A String containing the API request param value.
    */
    addParam(paramName: string, paramValue: string): void;
    /**
     * This is a setter method to set the API request body.
     * @param {object} requestBody - A Object containing the API request body.
    */
    setRequestBody(requestBody: object): void;
    getRequestBody(): object;
    /**
     * This method makes the Zoho CRM Rest API request.
     * @param {object} converterInstance A Converter class instance to call appendToRequest method.
     * @returns got instance or null
    */
    fireRequest(converterInstance: Converter | null): Promise<import("got").Response<string>>;
    setContentTypeHeader(): void;
    toString(): Promise<string>;
    proxyLog(requestProxy: RequestProxy): Promise<string>;
}
