/**
 * This class represents the Zoho CRM environment.
 */
declare class Environment {
    private url;
    private accountsUrl;
    private fileUploadUrl;
    private name;
    /**
     * Creates an Environment class instance with the specified parameters.
     * @param {string} url - A String representing the domain URL
     * @param {string} accountsUrl - A String representing the accounts URL to fetch tokens.
     * @param {string} fileUploadUrl - A string representing the file Upload URL
     * @param {string} name - A string
     */
    constructor(url: string, accountsUrl: string, fileUploadUrl: string, name: string);
    /**
     * The method is used to get the Zoho CRM API URL.
     * @returns {string} A String representing the Zoho CRM API URL.
     */
    getUrl(): string;
    /**
     * The method to get the Zoho CRM Accounts URL.
     * @returns {string} A String representing the accounts URL.
     */
    getAccountsUrl(): string;
    /**
     * The method to get the File Upload URL.
     * @returns {string} A String representing the File Upload URL.
     */
    getFileUploadUrl(): string;
    /**
     * This method to get name.
     * @return {string} A string representing the name.
     */
    getName(): string;
}
export { Environment as MasterModel, Environment as Environment };
